=======
Credits
=======

Development Lead
----------------

* Leonardo Giordani <giordani.leonardo@gmail.com>

Contributors
------------

* Michele D'Amico <michele.damico@gmail.com> (Mercurial support)
